/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of Print.xs. Do not edit this file, edit Print.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        ext/print/Print.xs
// Purpose:     XS for Print Framework
// Author:      Mattia Barbon
// Modified by:
// Created:     04/05/2001
// RCS-ID:      $Id: Print.xs 3300 2012-05-31 00:58:11Z mdootson $
// Copyright:   (c) 2001-2002, 2004-2006, 2008-2010 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"
#include "cpp/constants.h"
#include "cpp/overload.h"

#undef THIS

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif

#if wxPERL_USE_PRINTING_ARCHITECTURE
#define XSubPPtmpAAAA 1


/* INCLUDE:  Including 'XS/PrintData.xs' from 'Print.xs' */


/* INCLUDE:  Including 'XS/PageSetupDialog.xs' from 'XS/PrintData.xs' */


/* INCLUDE:  Including 'XS/PageSetupDialogData.xs' from 'XS/PageSetupDialog.xs' */


/* INCLUDE:  Including 'XS/Printer.xs' from 'XS/PageSetupDialogData.xs' */


/* INCLUDE:  Including 'XS/PrintDialogData.xs' from 'XS/Printer.xs' */


/* INCLUDE:  Including 'XS/PrintPreview.xs' from 'XS/PrintDialogData.xs' */


/* INCLUDE:  Including 'XS/Printout.xs' from 'XS/PrintPreview.xs' */


/* INCLUDE:  Including 'XS/PrintDialog.xs' from 'XS/Printout.xs' */

#include <wx/printdlg.h>
#include <wx/dc.h>

XS_EUPXS(XS_Wx__PrintDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialog_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent, data = 0");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPrintDialogData*	data;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPrintDialog *	RETVAL;

	if (items < 3)
	    data = 0;
	else {
    data = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::PrintDialogData" )
;
	}

	RETVAL = new wxPrintDialog(parent, data);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialog_GetPrintDialogData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialog_GetPrintDialogData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialog *    THIS = (wxPrintDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialog" )
;
	wxPrintDialogData *	RETVAL;
    RETVAL = new wxPrintDialogData( THIS->GetPrintDialogData() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialog_GetPrintDC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialog_GetPrintDC)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialog *    THIS = (wxPrintDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialog" )
;
	wxDC *	RETVAL;

	RETVAL = THIS->GetPrintDC();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::DC", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialog_ShowModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialog_ShowModal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialog *    THIS = (wxPrintDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->ShowModal();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/Printout.xs' from 'XS/PrintDialog.xs' */

#include <wx/print.h>
#include <wx/dcprint.h>
#include "cpp/printout.h"
#if defined( __WXMSW__ )
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__PrinterDC_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrinterDC_new)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, data");
    {
	wxPrintData*    data = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintData" )
;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPrinterDC *	RETVAL;
    RETVAL = new wxPrinterDC( *data );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrinterDC_GetPaperRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrinterDC_GetPaperRect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrinterDC *    THIS = (wxPrinterDC *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrinterDC" )
;
	wxRect *	RETVAL;
    RETVAL = new wxRect( THIS->GetPaperRect() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Printout_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, title = wxT(\"Printout\")");
    {
	wxString	title;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPrintout *	RETVAL;

	if (items < 2)
	    title = wxT("Printout");
	else {
    WXSTRING_INPUT( title, wxString, ST(1) )
;
	}
    RETVAL = new wxPlPrintout( CLASS, title );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printout_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_GetDC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetDC)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
	wxDC *	RETVAL;

	RETVAL = THIS->GetDC();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::DC", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printout_SetDC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_SetDC)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, dc");
    {
	wxDC*    dc = (wxDC *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::DC" )
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    wxPli_object_set_deleteable( aTHX_ ST(1), false );
    THIS->SetDC( dc );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_GetPageInfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetPageInfo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int minPage, maxPage, pageFrom, pageTo;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    THIS->wxPrintout::GetPageInfo( &minPage, &maxPage, &pageFrom, &pageTo );
    EXTEND( SP, 4 );
    PUSHs( sv_2mortal( newSViv( minPage ) ) );
    PUSHs( sv_2mortal( newSViv( maxPage ) ) );
    PUSHs( sv_2mortal( newSViv( pageFrom ) ) );
    PUSHs( sv_2mortal( newSViv( pageTo ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Printout_GetPageSizeMM); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetPageSizeMM)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int w, h;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    THIS->GetPageSizeMM( &w, &h );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( w ) ) );
    PUSHs( sv_2mortal( newSViv( h ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Printout_GetPageSizePixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetPageSizePixels)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int w, h;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    THIS->GetPageSizePixels( &w, &h );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( w ) ) );
    PUSHs( sv_2mortal( newSViv( h ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Printout_GetPPIPrinter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetPPIPrinter)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int w, h;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    THIS->GetPPIPrinter( &w, &h );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( w ) ) );
    PUSHs( sv_2mortal( newSViv( h ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Printout_GetPPIScreen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetPPIScreen)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int w, h;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    THIS->GetPPIScreen( &w, &h );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( w ) ) );
    PUSHs( sv_2mortal( newSViv( h ) ) );
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__Printout_GetPaperRectPixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetPaperRectPixels)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
	wxRect *	RETVAL;
    RETVAL = new wxRect( THIS->GetPaperRectPixels() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Printout_GetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetTitle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetTitle();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printout_HasPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_HasPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pageNum");
    {
	int	pageNum = (int)SvIV(ST(1))
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
	bool	RETVAL;
    RETVAL = THIS->wxPrintout::HasPage( pageNum );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printout_IsPreview); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_IsPreview)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
	bool	RETVAL;

	RETVAL = THIS->IsPreview();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__Printout_SetIsPreview); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_SetIsPreview)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, p");
    {
	bool	p = (bool)SvTRUE(ST(1))
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->SetIsPreview(p);
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__Printout_SetPreview); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_SetPreview)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, preview");
    {
	wxPrintPreview*    preview = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintPreview" )
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->SetPreview(preview);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_GetPreview); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetPreview)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
	wxPrintPreview *	RETVAL;

	RETVAL = THIS->GetPreview();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Printout_OnBeginDocument); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_OnBeginDocument)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, startPage, endPage");
    {
	int	startPage = (int)SvIV(ST(1))
;
	int	endPage = (int)SvIV(ST(2))
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
	bool	RETVAL;
    RETVAL = THIS->wxPrintout::OnBeginDocument( startPage, endPage );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printout_OnEndDocument); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_OnEndDocument)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    THIS->wxPrintout::OnEndDocument();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_OnBeginPrinting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_OnBeginPrinting)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    THIS->wxPrintout::OnBeginPrinting();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_OnEndPrinting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_OnEndPrinting)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    THIS->wxPrintout::OnEndPrinting();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_OnPreparePrinting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_OnPreparePrinting)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    THIS->wxPrintout::OnPreparePrinting();
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__Printout_FitThisSizeToPaper); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_FitThisSizeToPaper)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, imageSize");
    {
	wxSize    imageSize = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->FitThisSizeToPaper(imageSize);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_FitThisSizeToPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_FitThisSizeToPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, imageSize");
    {
	wxSize    imageSize = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->FitThisSizeToPage(imageSize);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_FitThisSizeToPageMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_FitThisSizeToPageMargins)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, imageSize, pageSetupData");
    {
	wxSize    imageSize = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxPageSetupDialogData*    pageSetupData = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::PageSetupDialogData" )
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->FitThisSizeToPageMargins(imageSize, *pageSetupData);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_MapScreenSizeToPaper); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_MapScreenSizeToPaper)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->MapScreenSizeToPaper();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_MapScreenSizeToPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_MapScreenSizeToPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->MapScreenSizeToPage();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_MapScreenSizeToPageMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_MapScreenSizeToPageMargins)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pageSetupData");
    {
	wxPageSetupDialogData*    pageSetupData = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PageSetupDialogData" )
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->MapScreenSizeToPageMargins(*pageSetupData);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_MapScreenSizeToDevice); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_MapScreenSizeToDevice)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->MapScreenSizeToDevice();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_GetLogicalPaperRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetLogicalPaperRect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
	wxRect *	RETVAL;
    RETVAL = new wxRect( THIS->GetLogicalPaperRect() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printout_GetLogicalPageRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetLogicalPageRect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
	wxRect *	RETVAL;
    RETVAL = new wxRect( THIS->GetLogicalPageRect() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printout_GetLogicalPageMarginsRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_GetLogicalPageMarginsRect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pageSetupData");
    {
	wxPageSetupDialogData*    pageSetupData = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PageSetupDialogData" )
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
	wxRect *	RETVAL;
    RETVAL = new wxRect( THIS->GetLogicalPageMarginsRect( *pageSetupData ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printout_SetLogicalOrigin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_SetLogicalOrigin)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxCoord	x = (wxCoord)SvIV(ST(1))
;
	wxCoord	y = (wxCoord)SvIV(ST(2))
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->SetLogicalOrigin(x, y);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_OffsetLogicalOrigin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_OffsetLogicalOrigin)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, xoff, yoff");
    {
	wxCoord	xoff = (wxCoord)SvIV(ST(1))
;
	wxCoord	yoff = (wxCoord)SvIV(ST(2))
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->OffsetLogicalOrigin(xoff, yoff);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_SetPageSizePixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_SetPageSizePixels)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, w, h");
    {
	int	w = (int)SvIV(ST(1))
;
	int	h = (int)SvIV(ST(2))
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->SetPageSizePixels(w, h);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_SetPageSizeMM); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_SetPageSizeMM)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, w, h");
    {
	int	w = (int)SvIV(ST(1))
;
	int	h = (int)SvIV(ST(2))
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->SetPageSizeMM(w, h);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_SetPPIScreen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_SetPPIScreen)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->SetPPIScreen(x, y);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_SetPPIPrinter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_SetPPIPrinter)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;

	THIS->SetPPIPrinter(x, y);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printout_SetPaperRectPixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printout_SetPaperRectPixels)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, paperRectPixels");
    {
	wxRect*    paperRectPixels = (wxRect *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Rect" )
;
	wxPrintout *    THIS = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printout" )
;
    THIS->SetPaperRectPixels( *paperRectPixels );
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'XS/PrintPreview.xs' from 'XS/Printout.xs' */

#include <wx/print.h>

XS_EUPXS(XS_Wx__PrintPreview_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_new)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "CLASS, printout, printoutForPrinting, data = 0");
    {
	wxPrintout*    printout = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Printout" )
;
	wxPrintout*    printoutForPrinting = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Printout" )
;
	wxPrintData*	data;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPrintPreview *	RETVAL;

	if (items < 4)
	    data = 0;
	else {
    data = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::PrintData" )
;
	}

	RETVAL = new wxPrintPreview(printout, printoutForPrinting, data);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPreview_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__PrintPreview_IsOk); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_IsOk)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	bool	RETVAL;

	RETVAL = THIS->IsOk();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__PrintPreview_GetCanvas); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_GetCanvas)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->GetCanvas();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPreview_GetCurrentPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_GetCurrentPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCurrentPage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPreview_GetFrame); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_GetFrame)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	wxFrame *	RETVAL;

	RETVAL = THIS->GetFrame();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPreview_GetMaxPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_GetMaxPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMaxPage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPreview_GetMinPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_GetMinPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMinPage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPreview_GetPrintout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_GetPrintout)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	wxPrintout *	RETVAL;

	RETVAL = THIS->GetPrintout();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPreview_GetPrintoutForPrinting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_GetPrintoutForPrinting)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	wxPrintout *	RETVAL;

	RETVAL = THIS->GetPrintoutForPrinting();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPreview_Ok); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_Ok)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	bool	RETVAL;

	RETVAL = THIS->Ok();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__PrintPreview_PaintPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_PaintPage)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, canvas, dc");
    {
	wxPreviewCanvas*    canvas = (wxPreviewCanvas *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PreviewCanvas" )
;
	wxDC*    dc = (wxDC *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::DC" )
;
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	bool	RETVAL;

	RETVAL = THIS->PaintPage(canvas, *dc);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_Wx__PrintPreview_PaintPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_PaintPage)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, window, dc");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxDC*    dc = (wxDC *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::DC" )
;
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	bool	RETVAL;

	RETVAL = THIS->PaintPage(window, *dc);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__PrintPreview_Print); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_Print)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, prompt");
    {
	bool	prompt = (bool)SvTRUE(ST(1))
;
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;
	bool	RETVAL;

	RETVAL = THIS->Print(prompt);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAAAJ 1


XS_EUPXS(XS_Wx__PrintPreview_SetCanvas); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_SetCanvas)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, canvas");
    {
	wxPreviewCanvas*    canvas = (wxPreviewCanvas *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PreviewCanvas" )
;
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;

	THIS->SetCanvas(canvas);
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAAAK 1


XS_EUPXS(XS_Wx__PrintPreview_SetCanvas); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_SetCanvas)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;

	THIS->SetCanvas(window);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__PrintPreview_SetCurrentPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_SetCurrentPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pageNum");
    {
	int	pageNum = (int)SvIV(ST(1))
;
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;

	THIS->SetCurrentPage(pageNum);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintPreview_SetFrame); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_SetFrame)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, frame");
    {
	wxFrame*    frame = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Frame" )
;
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;

	THIS->SetFrame(frame);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintPreview_SetPrintout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_SetPrintout)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, printout");
    {
	wxPrintout*    printout = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Printout" )
;
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;

	THIS->SetPrintout(printout);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintPreview_SetZoom); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPreview_SetZoom)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, percent");
    {
	int	percent = (int)SvIV(ST(1))
;
	wxPrintPreview *    THIS = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPreview" )
;

	THIS->SetZoom(percent);
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/PrintDialogData.xs' from 'XS/PrintPreview.xs' */

#include <wx/cmndata.h>

XS_EUPXS(XS_Wx__PrintDialogData_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPrintDialogData *	RETVAL;

	RETVAL = new wxPrintDialogData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAL 1


XS_EUPXS(XS_Wx__PrintDialogData_IsOk); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_IsOk)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->IsOk();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__PrintDialogData_EnableHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_EnableHelp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enable");
    {
	bool	enable = (bool)SvTRUE(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->EnableHelp(enable);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_EnablePageNumbers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_EnablePageNumbers)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enable");
    {
	bool	enable = (bool)SvTRUE(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->EnablePageNumbers(enable);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_EnablePrintToFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_EnablePrintToFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enable");
    {
	bool	enable = (bool)SvTRUE(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->EnablePrintToFile(enable);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_EnableSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_EnableSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enable");
    {
	bool	enable = (bool)SvTRUE(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->EnableSelection(enable);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_GetAllPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_GetAllPages)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetAllPages();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_GetCollate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_GetCollate)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetCollate();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_GetFromPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_GetFromPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFromPage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_GetMaxPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_GetMaxPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMaxPage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_GetMinPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_GetMinPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMinPage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_GetNoCopies); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_GetNoCopies)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetNoCopies();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_GetPrintData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_GetPrintData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	wxPrintData *	RETVAL;
    RETVAL = &THIS->GetPrintData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_GetPrintToFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_GetPrintToFile)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetPrintToFile();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetSelection();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_GetToPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_GetToPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetToPage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintDialogData_SetCollate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_SetCollate)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, collate");
    {
	bool	collate = (bool)SvTRUE(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->SetCollate(collate);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_SetFromPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_SetFromPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	int	page = (int)SvIV(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->SetFromPage(page);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_SetMaxPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_SetMaxPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	int	page = (int)SvIV(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->SetMaxPage(page);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_SetMinPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_SetMinPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	int	page = (int)SvIV(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->SetMinPage(page);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_SetNoCopies); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_SetNoCopies)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->SetNoCopies(n);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_SetPrintData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_SetPrintData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, printData");
    {
	wxPrintData*    printData = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintData" )
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;
    THIS->SetPrintData( *printData );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_SetPrintToFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_SetPrintToFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->SetPrintToFile(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintDialogData_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, selection");
    {
	bool	selection = (bool)SvTRUE(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->SetSelection(selection);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 ) && WXPERL_W_VERSION_LE( 2, 5, 3 )
#define XSubPPtmpAAAM 1


XS_EUPXS(XS_Wx__PrintDialogData_SetSetupDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_SetSetupDialog)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->SetSetupDialog(flag);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__PrintDialogData_SetToPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintDialogData_SetToPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	int	page = (int)SvIV(ST(1))
;
	wxPrintDialogData *    THIS = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintDialogData" )
;

	THIS->SetToPage(page);
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/Printer.xs' from 'XS/PrintDialogData.xs' */

#include <wx/print.h>
#include <wx/dc.h>

XS_EUPXS(XS_Wx__Printer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, data = 0");
    {
	wxPrintDialogData*	data;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPrinter *	RETVAL;

	if (items < 2)
	    data = 0;
	else {
    data = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintDialogData" )
;
	}

	RETVAL = new wxPrinter(data);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Printer", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printer_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printer_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrinter *    THIS = (wxPrinter *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printer" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::Printer", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printer_GetAbort); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_GetAbort)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrinter *    THIS = (wxPrinter *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printer" )
;
	bool	RETVAL;

	RETVAL = THIS->GetAbort();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printer_GetPrintDialogData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_GetPrintDialogData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrinter *    THIS = (wxPrinter *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printer" )
;
	wxPrintDialogData *	RETVAL;
    RETVAL = &THIS->GetPrintDialogData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printer_CreateAbortWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_CreateAbortWindow)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, parent, printout");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPrintout*    printout = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Printout" )
;
	wxPrinter *    THIS = (wxPrinter *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printer" )
;

	THIS->CreateAbortWindow(parent, printout);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printer_GetLastError); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_GetLastError)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	wxPrinterError	RETVAL;
	dXSTARG;
    RETVAL = wxPrinter::GetLastError();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printer_Print); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_Print)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, parent, printout, prompt = true");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPrintout*    printout = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Printout" )
;
	bool	prompt;
	wxPrinter *    THIS = (wxPrinter *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printer" )
;
	bool	RETVAL;

	if (items < 4)
	    prompt = true;
	else {
	    prompt = (bool)SvTRUE(ST(3))
;
	}

	RETVAL = THIS->Print(parent, printout, prompt);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printer_PrintDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_PrintDialog)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, parent");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPrinter *    THIS = (wxPrinter *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printer" )
;
	wxDC *	RETVAL;

	RETVAL = THIS->PrintDialog(parent);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::DC", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Printer_ReportError); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_ReportError)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, parent, printout, message");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPrintout*    printout = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Printout" )
;
	wxString	message;
	wxPrinter *    THIS = (wxPrinter *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printer" )
;

    WXSTRING_INPUT( message, wxString, ST(3) )
;
    THIS->ReportError( parent, printout, message );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Printer_Setup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Printer_Setup)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, parent");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPrinter *    THIS = (wxPrinter *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Printer" )
;
	bool	RETVAL;

	RETVAL = THIS->Setup(parent);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/PageSetupDialogData.xs' from 'XS/Printer.xs' */

#include <wx/cmndata.h>

XS_EUPXS(XS_Wx__PageSetupDialogData_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPageSetupDialogData *	RETVAL;

	RETVAL = new wxPageSetupDialogData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_EnableHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_EnableHelp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->EnableHelp(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_EnableMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_EnableMargins)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->EnableMargins(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_EnableOrientation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_EnableOrientation)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->EnableOrientation(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_EnablePaper); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_EnablePaper)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->EnablePaper(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_EnablePrinter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_EnablePrinter)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->EnablePrinter(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetDefaultMinMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetDefaultMinMargins)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetDefaultMinMargins();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetEnableMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetEnableMargins)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetEnableMargins();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetEnableOrientation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetEnableOrientation)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetEnableOrientation();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetEnablePaper); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetEnablePaper)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetEnablePaper();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetEnablePrinter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetEnablePrinter)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetEnablePrinter();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetEnableHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetEnableHelp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetEnableHelp();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetDefaultInfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetDefaultInfo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetDefaultInfo();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetMarginTopLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetMarginTopLeft)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->GetMarginTopLeft() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetMarginBottomRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetMarginBottomRight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->GetMarginBottomRight() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetMinMarginTopLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetMinMarginTopLeft)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->GetMinMarginTopLeft() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetMinMarginBottomRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetMinMarginBottomRight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->GetMinMarginBottomRight() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetPaperId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetPaperId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	wxPaperSize	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPaperId();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetPaperSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetPaperSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetPaperSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_GetPrintData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_GetPrintData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
	wxPrintData *	RETVAL;
    RETVAL = &THIS->GetPrintData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialogData_SetDefaultInfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_SetDefaultInfo)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->SetDefaultInfo(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_SetDefaultMinMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_SetDefaultMinMargins)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->SetDefaultMinMargins(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_SetMarginTopLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_SetMarginTopLeft)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->SetMarginTopLeft(point);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_SetMarginBottomRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_SetMarginBottomRight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->SetMarginBottomRight(point);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_SetMinMarginTopLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_SetMinMarginTopLeft)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->SetMinMarginTopLeft(point);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_SetMinMarginBottomRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_SetMinMarginBottomRight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->SetMinMarginBottomRight(point);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_SetPaperId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_SetPaperId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	wxPaperSize	id = (wxPaperSize)SvIV(ST(1))
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->SetPaperId(id);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_SetPaperSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_SetPaperSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;

	THIS->SetPaperSize(size);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialogData_SetPrintData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialogData_SetPrintData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, printData");
    {
	wxPrintData*    printData = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintData" )
;
	wxPageSetupDialogData *    THIS = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialogData" )
;
    THIS->SetPrintData( *printData );
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/PageSetupDialog.xs' from 'XS/PageSetupDialogData.xs' */

#include <wx/printdlg.h>

XS_EUPXS(XS_Wx__PageSetupDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialog_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent, data = 0");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPageSetupDialogData*	data;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPageSetupDialog *	RETVAL;

	if (items < 3)
	    data = 0;
	else {
    data = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::PageSetupDialogData" )
;
	}

	RETVAL = new wxPageSetupDialog(parent, data);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialog_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialog_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialog *    THIS = (wxPageSetupDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialog" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PageSetupDialog_GetPageSetupData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialog_GetPageSetupData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialog *    THIS = (wxPageSetupDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialog" )
;
	wxPageSetupDialogData *	RETVAL;
    RETVAL = &THIS->GetPageSetupData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PageSetupDialog_ShowModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PageSetupDialog_ShowModal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPageSetupDialog *    THIS = (wxPageSetupDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PageSetupDialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->ShowModal();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/PrintData.xs' from 'XS/PageSetupDialog.xs' */

#include <wx/cmndata.h>

XS_EUPXS(XS_Wx__PrintData_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPrintData *	RETVAL;
    RETVAL = new wxPrintData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAAAN 1


XS_EUPXS(XS_Wx__PrintData_GetBin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetBin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	wxPrintBin	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetBin();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAO 1


XS_EUPXS(XS_Wx__PrintData_IsOk); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_IsOk)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	bool	RETVAL;

	RETVAL = THIS->IsOk();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__PrintData_GetCollate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetCollate)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetCollate();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_GetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetColour();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_GetDuplex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetDuplex)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	wxDuplexMode	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetDuplex();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_GetNoCopies); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetNoCopies)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetNoCopies();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_GetOrientation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetOrientation)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetOrientation();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_GetPaperId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetPaperId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	wxPaperSize	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPaperId();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_GetPrinterName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetPrinterName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetPrinterName();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_GetQuality); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetQuality)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	wxPrintQuality	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetQuality();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAAAP 1


XS_EUPXS(XS_Wx__PrintData_SetBin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetBin)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bin");
    {
	wxPrintBin	bin = (wxPrintBin)SvIV(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetBin(bin);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__PrintData_SetCollate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetCollate)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, collate");
    {
	bool	collate = (bool)SvTRUE(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetCollate(collate);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_SetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	bool	colour = (bool)SvTRUE(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetColour(colour);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_SetDuplex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetDuplex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	wxDuplexMode	mode = (wxDuplexMode)SvIV(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetDuplex(mode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_SetNoCopies); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetNoCopies)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, noCopies");
    {
	int	noCopies = (int)SvIV(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetNoCopies(noCopies);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_SetOrientation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetOrientation)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, orientation");
    {
	int	orientation = (int)SvIV(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetOrientation(orientation);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_SetPaperId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetPaperId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, paperId");
    {
	wxPaperSize	paperId = (wxPaperSize)SvIV(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetPaperId(paperId);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_SetPrinterName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetPrinterName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxString	name;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	THIS->SetPrinterName(name);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_SetQuality); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetQuality)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, quality");
    {
	wxPrintQuality	quality = (wxPrintQuality)SvIV(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetQuality(quality);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSubPPtmpAAAQ 1


XS_EUPXS(XS_Wx__PrintData_IsOrientationReversed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_IsOrientationReversed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	bool	RETVAL;

	RETVAL = THIS->IsOrientationReversed();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_GetPrintMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetPrintMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	wxPrintMode	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPrintMode();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_GetMedia); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetMedia)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMedia();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_SetOrientationReversed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetOrientationReversed)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, reversed");
    {
	bool	reversed = (bool)SvTRUE(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetOrientationReversed(reversed);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_SetMedia); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetMedia)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, media");
    {
	int	media = (int)SvIV(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetMedia(media);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_SetPrintMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetPrintMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, printMode");
    {
	wxPrintMode	printMode = (wxPrintMode)SvIV(ST(1))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetPrintMode(printMode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_GetFilename); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetFilename)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetFilename();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_SetFilename); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetFilename)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filename");
    {
	wxString	filename;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

    WXSTRING_INPUT( filename, wxString, ST(1) )
;

	THIS->SetFilename(filename);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_GetPrivData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetPrivData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	char *	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPrivData();
	sv_setpv(TARG, RETVAL);
	XSprePUSH;
	PUSHTARG;
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_GetPrivDataLen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_GetPrivDataLen)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPrivDataLen();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintData_SetPrivData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_SetPrivData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, privData, len");
    {
	char*	privData = (char *)SvPV_nolen(ST(1))
;
	int	len = (int)SvIV(ST(2))
;
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->SetPrivData(privData, len);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_ConvertToNative); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_ConvertToNative)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->ConvertToNative();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintData_ConvertFromNative); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintData_ConvertFromNative)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintData *    THIS = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintData" )
;

	THIS->ConvertFromNative();
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'Print.xs' from 'XS/PrintData.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/Preview.xsp' from 'Print.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/print.h>
#include "xspp/previewframe.h"
#include "xspp/previewcontrolbar.h"
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PreviewControlBar_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_new)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, preview, buttons, parent, pos= wxDefaultPosition, size= wxDefaultSize, style= wxTAB_TRAVERSAL, name= wxPanelNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPreviewControlBar *	RETVAL;
	wxPrintPreview*    preview = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintPreview" )
;
	long	buttons = (long)SvIV(ST(2))
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Window" )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxTAB_TRAVERSAL;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    try {
      RETVAL = new wxPreviewControlBar( preview, buttons, parent, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PreviewControlBar_CreateButtons); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_CreateButtons)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
    try {
      THIS->CreateButtons();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PreviewControlBar_GetPrintPreview); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_GetPrintPreview)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
	wxPrintPreviewBase *	RETVAL;
    try {
      RETVAL = THIS->GetPrintPreview();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PreviewControlBar_GetZoomControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_GetZoomControl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetZoomControl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PreviewControlBar_SetZoomControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_SetZoomControl)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, zoom");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
	int	zoom = (int)SvIV(ST(1))
;
    try {
      THIS->SetZoomControl( zoom );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PreviewControlBar_OnNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_OnNext)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
    try {
      THIS->OnNext();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PreviewControlBar_OnPrevious); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_OnPrevious)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
    try {
      THIS->OnPrevious();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PreviewControlBar_OnFirst); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_OnFirst)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
    try {
      THIS->OnFirst();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PreviewControlBar_OnLast); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_OnLast)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
    try {
      THIS->OnLast();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 9, 2 )
#define XSpp_013dcc84_080461
#define XSubPPtmpAAAR 1


XS_EUPXS(XS_Wx__PreviewControlBar_OnGoto); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_OnGoto)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
    try {
      THIS->OnGoto();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#else
#define XSpp_013dcc84_039217
#define XSubPPtmpAAAS 1


XS_EUPXS(XS_Wx__PreviewControlBar_OnGotoPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_OnGotoPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
    try {
      THIS->OnGotoPage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_013dcc84_004662
#define XSubPPtmpAAAT 1


XS_EUPXS(XS_Wx__PreviewControlBar_OnPrint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewControlBar_OnPrint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewControlBar *    THIS = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewControlBar" )
;
    try {
      THIS->OnPrint();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#define CreateButtons wxPreviewControlBar::CreateButtons
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlPreviewControlBar_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewControlBar_new)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, preview, buttons, parent, pos= wxDefaultPosition, size= wxDefaultSize, style= wxTAB_TRAVERSAL, name= wxPanelNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlPreviewControlBar *	RETVAL;
	wxPrintPreview*    preview = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintPreview" )
;
	long	buttons = (long)SvIV(ST(2))
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Window" )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxTAB_TRAVERSAL;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
     RETVAL = new wxPlPreviewControlBar
                    ( CLASS, preview, buttons, parent, pos, size,
                      style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PlPreviewControlBar_CreateButtons); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewControlBar_CreateButtons)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPreviewControlBar *    THIS = (wxPlPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewControlBar" )
;
    try {
      THIS->CreateButtons();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#undef CreateButtons
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_013dcc84_031623
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAU 1


XS_EUPXS(XS_Wx__PreviewFrame_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewFrame_new)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, preview, parent, title, pos= wxDefaultPosition, size= wxDefaultSize, style= wxDEFAULT_FRAME_STYLE, name= wxFrameNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPreviewFrame *	RETVAL;
	wxPrintPreview*    preview = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintPreview" )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_FRAME_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxFrameNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    try {
      RETVAL = new wxPreviewFrame( preview, parent, title, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#else
#define XSpp_013dcc84_014857
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAV 1


XS_EUPXS(XS_Wx__PreviewFrame_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewFrame_new)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, preview, parent, title, pos= wxDefaultPosition, size= wxDefaultSize, style= wxDEFAULT_FRAME_STYLE, name= wxFrameNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPreviewFrame *	RETVAL;
	wxPrintPreview*    preview = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintPreview" )
;
	wxFrame*    parent = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Frame" )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_FRAME_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxFrameNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    try {
      RETVAL = new wxPreviewFrame( preview, parent, title, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif

XS_EUPXS(XS_Wx__PreviewFrame_Initialize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewFrame_Initialize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewFrame *    THIS = (wxPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewFrame" )
;
    try {
      THIS->Initialize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PreviewFrame_CreateCanvas); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewFrame_CreateCanvas)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewFrame *    THIS = (wxPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewFrame" )
;
    try {
      THIS->CreateCanvas();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PreviewFrame_CreateControlBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewFrame_CreateControlBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewFrame *    THIS = (wxPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewFrame" )
;
    try {
      THIS->CreateControlBar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 4 )
#define XSpp_013dcc84_078888
#define XSubPPtmpAAAW 1


XS_EUPXS(XS_Wx__PreviewFrame_GetControlBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewFrame_GetControlBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPreviewFrame *    THIS = (wxPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PreviewFrame" )
;
	wxPreviewControlBar *	RETVAL;
    try {
      RETVAL = THIS->GetControlBar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#define Initialize wxPreviewFrame::Initialize
#define CreateCanvas wxPreviewFrame::CreateCanvas
#define CreateControlBar wxPreviewFrame::CreateControlBar
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_013dcc84_052847
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAX 1


XS_EUPXS(XS_Wx__PlPreviewFrame_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_new)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, preview, parent, title, pos= wxDefaultPosition, size= wxDefaultSize, style= wxDEFAULT_FRAME_STYLE, name= wxFrameNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlPreviewFrame *	RETVAL;
	wxPrintPreview*    preview = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintPreview" )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_FRAME_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxFrameNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
     RETVAL = new wxPlPreviewFrame
                    ( CLASS, preview, parent, title, pos, size, style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#else
#define XSpp_013dcc84_087329
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAY 1


XS_EUPXS(XS_Wx__PlPreviewFrame_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_new)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, preview, parent, title, pos= wxDefaultPosition, size= wxDefaultSize, style= wxDEFAULT_FRAME_STYLE, name= wxFrameNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlPreviewFrame *	RETVAL;
	wxPrintPreview*    preview = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintPreview" )
;
	wxFrame*    parent = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Frame" )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_FRAME_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxFrameNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
     RETVAL = new wxPlPreviewFrame
                    ( CLASS, preview, parent, title, pos, size, style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_013dcc84_022517
#define XSubPPtmpAAAZ 1


XS_EUPXS(XS_Wx__PlPreviewFrame_GetPreviewCanvas); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_GetPreviewCanvas)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
	wxPreviewCanvas *	RETVAL;
    try {
      RETVAL = THIS->GetPreviewCanvas();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSpp_013dcc84_084465
#define XSubPPtmpAABA 1


XS_EUPXS(XS_Wx__PlPreviewFrame_GetPreviewCanvas); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_GetPreviewCanvas)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetPreviewCanvas();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__PlPreviewFrame_GetPreviewControlBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_GetPreviewControlBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
	wxPreviewControlBar *	RETVAL;
    try {
      RETVAL = THIS->GetPreviewControlBar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PlPreviewFrame_GetPrintPreview); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_GetPrintPreview)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
	wxPrintPreviewBase *	RETVAL;
    try {
      RETVAL = THIS->GetPrintPreview();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_013dcc84_049877
#define XSubPPtmpAABB 1


XS_EUPXS(XS_Wx__PlPreviewFrame_SetPreviewCanvas); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_SetPreviewCanvas)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, p");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
	wxPreviewCanvas*    p = (wxPreviewCanvas *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PreviewCanvas" )
;
    try {
      THIS->SetPreviewCanvas( p );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#else
#define XSpp_013dcc84_047272
#define XSubPPtmpAABC 1


XS_EUPXS(XS_Wx__PlPreviewFrame_SetPreviewCanvas); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_SetPreviewCanvas)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, p");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
	wxWindow*    p = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->SetPreviewCanvas( p );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__PlPreviewFrame_SetPreviewControlBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_SetPreviewControlBar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, p");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
	wxPreviewControlBar*    p = (wxPreviewControlBar *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PreviewControlBar" )
;
    try {
      THIS->SetPreviewControlBar( p );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PlPreviewFrame_SetPrintPreview); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_SetPrintPreview)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, p");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
	wxPrintPreviewBase*    p = (wxPrintPreviewBase *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintPreviewBase" )
;
    try {
      THIS->SetPrintPreview( p );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PlPreviewFrame_Initialize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_Initialize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
    try {
      THIS->Initialize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PlPreviewFrame_CreateCanvas); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_CreateCanvas)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
    try {
      THIS->CreateCanvas();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PlPreviewFrame_CreateControlBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPreviewFrame_CreateControlBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPreviewFrame *    THIS = (wxPlPreviewFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPreviewFrame" )
;
    try {
      THIS->CreateControlBar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#undef Initialize
#undef CreateCanvas
#undef CreateControlBar

XS_EUPXS(XS_Wx__PreviewCanvas_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PreviewCanvas_new)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "CLASS, preview, parent, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxT(\"canvas\")");
    {
	wxPrintPreview*    preview = (wxPrintPreview *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintPreview" )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPreviewCanvas *	RETVAL;

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxT("canvas");
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}

	RETVAL = new wxPreviewCanvas(preview, parent, pos, size, style, name);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Print.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/Preview.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/PrintFactory.xsp' from 'Print.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 5, 4 )
#define XSubPPtmpAABD 1


XS_EUPXS(XS_Wx__PrintFactory_CreatePrinter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_CreatePrinter)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, data");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	wxPrinterBase *	RETVAL;
	wxPrintDialogData*    data = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintDialogData" )
;
    try {
      RETVAL = THIS->CreatePrinter( data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_CreatePrintPreviewDD); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_CreatePrintPreviewDD)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, preview, printout= NULL, data= NULL");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	wxPrintPreviewBase *	RETVAL;
	wxPrintout*    preview = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Printout" )
;
	wxPrintout*	printout;
	wxPrintDialogData*	data;

	if (items < 3)
	    printout = NULL;
	else {
    printout = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Printout" )
;
	}

	if (items < 4)
	    data = NULL;
	else {
    data = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::PrintDialogData" )
;
	}
    try {
      RETVAL = THIS->CreatePrintPreview( preview, printout, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_CreatePrintPreviewD); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_CreatePrintPreviewD)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, preview, printout, data");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	wxPrintPreviewBase *	RETVAL;
	wxPrintout*    preview = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Printout" )
;
	wxPrintout*    printout = (wxPrintout *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Printout" )
;
	wxPrintData*    data = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::PrintData" )
;
    try {
      RETVAL = THIS->CreatePrintPreview( preview, printout, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_CreatePrintDialogDD); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_CreatePrintDialogDD)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, parent, data= NULL");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	wxPrintDialogBase *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPrintDialogData*	data;

	if (items < 3)
	    data = NULL;
	else {
    data = (wxPrintDialogData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::PrintDialogData" )
;
	}
    try {
      RETVAL = THIS->CreatePrintDialog( parent, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_CreatePrintDialogD); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_CreatePrintDialogD)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, parent, data");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	wxPrintDialogBase *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPrintData*    data = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::PrintData" )
;
    try {
      RETVAL = THIS->CreatePrintDialog( parent, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_CreatePageSetupDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_CreatePageSetupDialog)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, parent, data= NULL");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	wxPageSetupDialogBase *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPageSetupDialogData*	data;

	if (items < 3)
	    data = NULL;
	else {
    data = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::PageSetupDialogData" )
;
	}
    try {
      RETVAL = THIS->CreatePageSetupDialog( parent, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_HasPrintSetupDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_HasPrintSetupDialog)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasPrintSetupDialog();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_CreatePrintSetupDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_CreatePrintSetupDialog)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, parent, data");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	wxDialog *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxPrintData*    data = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::PrintData" )
;
    try {
      RETVAL = THIS->CreatePrintSetupDialog( parent, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_HasOwnPrintToFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_HasOwnPrintToFile)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasOwnPrintToFile();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_HasPrinterLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_HasPrinterLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasPrinterLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_CreatePrinterLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_CreatePrinterLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->CreatePrinterLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_HasStatusLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_HasStatusLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasStatusLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_CreateStatusLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_CreateStatusLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->CreateStatusLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintFactory_SetPrintFactory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_SetPrintFactory)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, factory");
    {
	wxPrintFactory*    factory = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintFactory" )
;
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
    wxPrintFactory::SetPrintFactory( factory );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintFactory_GetFactory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintFactory_GetFactory)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintFactory *    THIS = (wxPrintFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintFactory" )
;
	wxPrintFactory *	RETVAL;
    RETVAL = wxPrintFactory::GetFactory();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::PrintFactory" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Print.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/PrintFactory.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/PaperDatabase.xsp' from 'Print.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/paper.h>

XS_EUPXS(XS_Wx__PrintPaperType_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperType_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPaperType *    THIS = (wxPrintPaperType *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperType" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperType_GetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperType_GetId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPaperType *    THIS = (wxPrintPaperType *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperType" )
;
	wxPaperSize	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetId();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperType_GetPlatformId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperType_GetPlatformId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPaperType *    THIS = (wxPrintPaperType *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperType" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetPlatformId();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperType_GetWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperType_GetWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPaperType *    THIS = (wxPrintPaperType *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperType" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperType_GetHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperType_GetHeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPaperType *    THIS = (wxPrintPaperType *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperType" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetHeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperType_GetSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperType_GetSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPaperType *    THIS = (wxPrintPaperType *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperType" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperType_GetSizeMM); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperType_GetSizeMM)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPaperType *    THIS = (wxPrintPaperType *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperType" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetSizeMM();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperType_GetSizeDeviceUnits); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperType_GetSizeDeviceUnits)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPaperType *    THIS = (wxPrintPaperType *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperType" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetSizeDeviceUnits();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_AddPaperType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_AddPaperType)
{
    dVAR; dXSARGS;
    if (items != 6)
       croak_xs_usage(cv,  "THIS, paperId, platformId, name, w, h");
    {
	wxPaperSize	paperId = (wxPaperSize)SvIV(ST(1))
;
	int	platformId = (int)SvIV(ST(2))
;
	wxString	name;
	int	w = (int)SvIV(ST(4))
;
	int	h = (int)SvIV(ST(5))
;
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;

    WXSTRING_INPUT( name, wxString, ST(3) )
;

	THIS->AddPaperType(paperId, platformId, name, w, h);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_FindPaperType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_FindPaperType)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wsiz, FindPaperTypeBySize )
        MATCH_REDISP( wxPliOvl_n, FindPaperTypeById )
        MATCH_REDISP( wxPliOvl_s, FindPaperTypeByName )
    END_OVERLOAD( "Wx::PrintPaperDatabase::FindPaperType" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_FindPaperTypeByName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_FindPaperTypeByName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxString	name;
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;
	wxPrintPaperType *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    RETVAL = THIS->FindPaperType(name);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_FindPaperTypeById); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_FindPaperTypeById)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	wxPaperSize	id = (wxPaperSize)SvIV(ST(1))
;
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;
	wxPrintPaperType *	RETVAL;
    RETVAL = THIS->FindPaperType(id); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_FindPaperTypeBySize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_FindPaperTypeBySize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;
	wxPrintPaperType *	RETVAL;
    RETVAL = THIS->FindPaperType(size); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_FindPaperTypeByPlatformId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_FindPaperTypeByPlatformId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	int	id = (int)SvIV(ST(1))
;
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;
	wxPrintPaperType *	RETVAL;

	RETVAL = THIS->FindPaperTypeByPlatformId(id);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_ConvertNameToId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_ConvertNameToId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxString	name;
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;
	wxPaperSize	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	RETVAL = THIS->ConvertNameToId(name);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_ConvertIdToName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_ConvertIdToName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, paperId");
    {
	wxPaperSize	paperId = (wxPaperSize)SvIV(ST(1))
;
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;
	wxString	RETVAL;

	RETVAL = THIS->ConvertIdToName(paperId);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_GetSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_GetSize)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wsiz, GetPaperSize )
        MATCH_REDISP( wxPliOvl_n, GetSizeSize )
    END_OVERLOAD( "Wx::PrintPaperDatabase::GetSize" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_GetSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_GetSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, paperId");
    {
	int	paperId = (int)SvIV(ST(1))
;
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;
	wxSize	RETVAL;
    RETVAL = THIS->GetSize((wxPaperSize)paperId);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_GetPaperSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_GetPaperSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;
	wxPaperSize	RETVAL;
	dXSTARG;
    RETVAL = THIS->GetSize(size); 
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_Item); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_Item)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	size_t    index = (size_t)SvUV( ST(1) )
;
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;
	wxPrintPaperType *	RETVAL;

	RETVAL = THIS->Item(index);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PrintPaperDatabase_GetCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PrintPaperDatabase_GetCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPrintPaperDatabase *    THIS = (wxPrintPaperDatabase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PrintPaperDatabase" )
;
	size_t	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCount();
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Print.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/PaperDatabase.xsp' */

#include "cpp/pr_constants.cpp"
#include "cpp/ovl_const.cpp"
#endif
#if defined(__WXMSW__)
#undef XS
#define XS( name ) WXXS( name )
#endif
#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx__Print); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx__Print)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

#if XSubPPtmpAAAA
        newXS_deffile("Wx::PrintDialog::new", XS_Wx__PrintDialog_new);
        newXS_deffile("Wx::PrintDialog::GetPrintDialogData", XS_Wx__PrintDialog_GetPrintDialogData);
        newXS_deffile("Wx::PrintDialog::GetPrintDC", XS_Wx__PrintDialog_GetPrintDC);
        newXS_deffile("Wx::PrintDialog::ShowModal", XS_Wx__PrintDialog_ShowModal);
#if XSubPPtmpAAAB
        newXS_deffile("Wx::PrinterDC::new", XS_Wx__PrinterDC_new);
        newXS_deffile("Wx::PrinterDC::GetPaperRect", XS_Wx__PrinterDC_GetPaperRect);
#endif
        newXS_deffile("Wx::Printout::new", XS_Wx__Printout_new);
        newXS_deffile("Wx::Printout::Destroy", XS_Wx__Printout_Destroy);
        newXS_deffile("Wx::Printout::GetDC", XS_Wx__Printout_GetDC);
        newXS_deffile("Wx::Printout::SetDC", XS_Wx__Printout_SetDC);
        newXS_deffile("Wx::Printout::GetPageInfo", XS_Wx__Printout_GetPageInfo);
        newXS_deffile("Wx::Printout::GetPageSizeMM", XS_Wx__Printout_GetPageSizeMM);
        newXS_deffile("Wx::Printout::GetPageSizePixels", XS_Wx__Printout_GetPageSizePixels);
        newXS_deffile("Wx::Printout::GetPPIPrinter", XS_Wx__Printout_GetPPIPrinter);
        newXS_deffile("Wx::Printout::GetPPIScreen", XS_Wx__Printout_GetPPIScreen);
#if XSubPPtmpAAAC
        newXS_deffile("Wx::Printout::GetPaperRectPixels", XS_Wx__Printout_GetPaperRectPixels);
#endif
        newXS_deffile("Wx::Printout::GetTitle", XS_Wx__Printout_GetTitle);
        newXS_deffile("Wx::Printout::HasPage", XS_Wx__Printout_HasPage);
        newXS_deffile("Wx::Printout::IsPreview", XS_Wx__Printout_IsPreview);
#if XSubPPtmpAAAD
        newXS_deffile("Wx::Printout::SetIsPreview", XS_Wx__Printout_SetIsPreview);
#endif
#if XSubPPtmpAAAE
        newXS_deffile("Wx::Printout::SetPreview", XS_Wx__Printout_SetPreview);
        newXS_deffile("Wx::Printout::GetPreview", XS_Wx__Printout_GetPreview);
#endif
        newXS_deffile("Wx::Printout::OnBeginDocument", XS_Wx__Printout_OnBeginDocument);
        newXS_deffile("Wx::Printout::OnEndDocument", XS_Wx__Printout_OnEndDocument);
        newXS_deffile("Wx::Printout::OnBeginPrinting", XS_Wx__Printout_OnBeginPrinting);
        newXS_deffile("Wx::Printout::OnEndPrinting", XS_Wx__Printout_OnEndPrinting);
        newXS_deffile("Wx::Printout::OnPreparePrinting", XS_Wx__Printout_OnPreparePrinting);
#if XSubPPtmpAAAF
        newXS_deffile("Wx::Printout::FitThisSizeToPaper", XS_Wx__Printout_FitThisSizeToPaper);
        newXS_deffile("Wx::Printout::FitThisSizeToPage", XS_Wx__Printout_FitThisSizeToPage);
        newXS_deffile("Wx::Printout::FitThisSizeToPageMargins", XS_Wx__Printout_FitThisSizeToPageMargins);
        newXS_deffile("Wx::Printout::MapScreenSizeToPaper", XS_Wx__Printout_MapScreenSizeToPaper);
        newXS_deffile("Wx::Printout::MapScreenSizeToPage", XS_Wx__Printout_MapScreenSizeToPage);
        newXS_deffile("Wx::Printout::MapScreenSizeToPageMargins", XS_Wx__Printout_MapScreenSizeToPageMargins);
        newXS_deffile("Wx::Printout::MapScreenSizeToDevice", XS_Wx__Printout_MapScreenSizeToDevice);
        newXS_deffile("Wx::Printout::GetLogicalPaperRect", XS_Wx__Printout_GetLogicalPaperRect);
        newXS_deffile("Wx::Printout::GetLogicalPageRect", XS_Wx__Printout_GetLogicalPageRect);
        newXS_deffile("Wx::Printout::GetLogicalPageMarginsRect", XS_Wx__Printout_GetLogicalPageMarginsRect);
        newXS_deffile("Wx::Printout::SetLogicalOrigin", XS_Wx__Printout_SetLogicalOrigin);
        newXS_deffile("Wx::Printout::OffsetLogicalOrigin", XS_Wx__Printout_OffsetLogicalOrigin);
        newXS_deffile("Wx::Printout::SetPageSizePixels", XS_Wx__Printout_SetPageSizePixels);
        newXS_deffile("Wx::Printout::SetPageSizeMM", XS_Wx__Printout_SetPageSizeMM);
        newXS_deffile("Wx::Printout::SetPPIScreen", XS_Wx__Printout_SetPPIScreen);
        newXS_deffile("Wx::Printout::SetPPIPrinter", XS_Wx__Printout_SetPPIPrinter);
        newXS_deffile("Wx::Printout::SetPaperRectPixels", XS_Wx__Printout_SetPaperRectPixels);
#endif
        newXS_deffile("Wx::PrintPreview::new", XS_Wx__PrintPreview_new);
        newXS_deffile("Wx::PrintPreview::Destroy", XS_Wx__PrintPreview_Destroy);
#if XSubPPtmpAAAG
        newXS_deffile("Wx::PrintPreview::IsOk", XS_Wx__PrintPreview_IsOk);
#endif
        newXS_deffile("Wx::PrintPreview::GetCanvas", XS_Wx__PrintPreview_GetCanvas);
        newXS_deffile("Wx::PrintPreview::GetCurrentPage", XS_Wx__PrintPreview_GetCurrentPage);
        newXS_deffile("Wx::PrintPreview::GetFrame", XS_Wx__PrintPreview_GetFrame);
        newXS_deffile("Wx::PrintPreview::GetMaxPage", XS_Wx__PrintPreview_GetMaxPage);
        newXS_deffile("Wx::PrintPreview::GetMinPage", XS_Wx__PrintPreview_GetMinPage);
        newXS_deffile("Wx::PrintPreview::GetPrintout", XS_Wx__PrintPreview_GetPrintout);
        newXS_deffile("Wx::PrintPreview::GetPrintoutForPrinting", XS_Wx__PrintPreview_GetPrintoutForPrinting);
        newXS_deffile("Wx::PrintPreview::Ok", XS_Wx__PrintPreview_Ok);
#if XSubPPtmpAAAH
        newXS_deffile("Wx::PrintPreview::PaintPage", XS_Wx__PrintPreview_PaintPage);
#endif
#if XSubPPtmpAAAI
        newXS_deffile("Wx::PrintPreview::PaintPage", XS_Wx__PrintPreview_PaintPage);
#endif
        newXS_deffile("Wx::PrintPreview::Print", XS_Wx__PrintPreview_Print);
#if XSubPPtmpAAAJ
        newXS_deffile("Wx::PrintPreview::SetCanvas", XS_Wx__PrintPreview_SetCanvas);
#endif
#if XSubPPtmpAAAK
        newXS_deffile("Wx::PrintPreview::SetCanvas", XS_Wx__PrintPreview_SetCanvas);
#endif
        newXS_deffile("Wx::PrintPreview::SetCurrentPage", XS_Wx__PrintPreview_SetCurrentPage);
        newXS_deffile("Wx::PrintPreview::SetFrame", XS_Wx__PrintPreview_SetFrame);
        newXS_deffile("Wx::PrintPreview::SetPrintout", XS_Wx__PrintPreview_SetPrintout);
        newXS_deffile("Wx::PrintPreview::SetZoom", XS_Wx__PrintPreview_SetZoom);
        newXS_deffile("Wx::PrintDialogData::new", XS_Wx__PrintDialogData_new);
        newXS_deffile("Wx::PrintDialogData::Destroy", XS_Wx__PrintDialogData_Destroy);
#if XSubPPtmpAAAL
        newXS_deffile("Wx::PrintDialogData::IsOk", XS_Wx__PrintDialogData_IsOk);
#endif
        newXS_deffile("Wx::PrintDialogData::EnableHelp", XS_Wx__PrintDialogData_EnableHelp);
        newXS_deffile("Wx::PrintDialogData::EnablePageNumbers", XS_Wx__PrintDialogData_EnablePageNumbers);
        newXS_deffile("Wx::PrintDialogData::EnablePrintToFile", XS_Wx__PrintDialogData_EnablePrintToFile);
        newXS_deffile("Wx::PrintDialogData::EnableSelection", XS_Wx__PrintDialogData_EnableSelection);
        newXS_deffile("Wx::PrintDialogData::GetAllPages", XS_Wx__PrintDialogData_GetAllPages);
        newXS_deffile("Wx::PrintDialogData::GetCollate", XS_Wx__PrintDialogData_GetCollate);
        newXS_deffile("Wx::PrintDialogData::GetFromPage", XS_Wx__PrintDialogData_GetFromPage);
        newXS_deffile("Wx::PrintDialogData::GetMaxPage", XS_Wx__PrintDialogData_GetMaxPage);
        newXS_deffile("Wx::PrintDialogData::GetMinPage", XS_Wx__PrintDialogData_GetMinPage);
        newXS_deffile("Wx::PrintDialogData::GetNoCopies", XS_Wx__PrintDialogData_GetNoCopies);
        newXS_deffile("Wx::PrintDialogData::GetPrintData", XS_Wx__PrintDialogData_GetPrintData);
        newXS_deffile("Wx::PrintDialogData::GetPrintToFile", XS_Wx__PrintDialogData_GetPrintToFile);
        newXS_deffile("Wx::PrintDialogData::GetSelection", XS_Wx__PrintDialogData_GetSelection);
        newXS_deffile("Wx::PrintDialogData::GetToPage", XS_Wx__PrintDialogData_GetToPage);
        newXS_deffile("Wx::PrintDialogData::SetCollate", XS_Wx__PrintDialogData_SetCollate);
        newXS_deffile("Wx::PrintDialogData::SetFromPage", XS_Wx__PrintDialogData_SetFromPage);
        newXS_deffile("Wx::PrintDialogData::SetMaxPage", XS_Wx__PrintDialogData_SetMaxPage);
        newXS_deffile("Wx::PrintDialogData::SetMinPage", XS_Wx__PrintDialogData_SetMinPage);
        newXS_deffile("Wx::PrintDialogData::SetNoCopies", XS_Wx__PrintDialogData_SetNoCopies);
        newXS_deffile("Wx::PrintDialogData::SetPrintData", XS_Wx__PrintDialogData_SetPrintData);
        newXS_deffile("Wx::PrintDialogData::SetPrintToFile", XS_Wx__PrintDialogData_SetPrintToFile);
        newXS_deffile("Wx::PrintDialogData::SetSelection", XS_Wx__PrintDialogData_SetSelection);
#if XSubPPtmpAAAM
        newXS_deffile("Wx::PrintDialogData::SetSetupDialog", XS_Wx__PrintDialogData_SetSetupDialog);
#endif
        newXS_deffile("Wx::PrintDialogData::SetToPage", XS_Wx__PrintDialogData_SetToPage);
        newXS_deffile("Wx::Printer::new", XS_Wx__Printer_new);
        newXS_deffile("Wx::Printer::CLONE", XS_Wx__Printer_CLONE);
        newXS_deffile("Wx::Printer::DESTROY", XS_Wx__Printer_DESTROY);
        newXS_deffile("Wx::Printer::GetAbort", XS_Wx__Printer_GetAbort);
        newXS_deffile("Wx::Printer::GetPrintDialogData", XS_Wx__Printer_GetPrintDialogData);
        newXS_deffile("Wx::Printer::CreateAbortWindow", XS_Wx__Printer_CreateAbortWindow);
        newXS_deffile("Wx::Printer::GetLastError", XS_Wx__Printer_GetLastError);
        newXS_deffile("Wx::Printer::Print", XS_Wx__Printer_Print);
        newXS_deffile("Wx::Printer::PrintDialog", XS_Wx__Printer_PrintDialog);
        newXS_deffile("Wx::Printer::ReportError", XS_Wx__Printer_ReportError);
        newXS_deffile("Wx::Printer::Setup", XS_Wx__Printer_Setup);
        newXS_deffile("Wx::PageSetupDialogData::new", XS_Wx__PageSetupDialogData_new);
        newXS_deffile("Wx::PageSetupDialogData::Destroy", XS_Wx__PageSetupDialogData_Destroy);
        newXS_deffile("Wx::PageSetupDialogData::EnableHelp", XS_Wx__PageSetupDialogData_EnableHelp);
        newXS_deffile("Wx::PageSetupDialogData::EnableMargins", XS_Wx__PageSetupDialogData_EnableMargins);
        newXS_deffile("Wx::PageSetupDialogData::EnableOrientation", XS_Wx__PageSetupDialogData_EnableOrientation);
        newXS_deffile("Wx::PageSetupDialogData::EnablePaper", XS_Wx__PageSetupDialogData_EnablePaper);
        newXS_deffile("Wx::PageSetupDialogData::EnablePrinter", XS_Wx__PageSetupDialogData_EnablePrinter);
        newXS_deffile("Wx::PageSetupDialogData::GetDefaultMinMargins", XS_Wx__PageSetupDialogData_GetDefaultMinMargins);
        newXS_deffile("Wx::PageSetupDialogData::GetEnableMargins", XS_Wx__PageSetupDialogData_GetEnableMargins);
        newXS_deffile("Wx::PageSetupDialogData::GetEnableOrientation", XS_Wx__PageSetupDialogData_GetEnableOrientation);
        newXS_deffile("Wx::PageSetupDialogData::GetEnablePaper", XS_Wx__PageSetupDialogData_GetEnablePaper);
        newXS_deffile("Wx::PageSetupDialogData::GetEnablePrinter", XS_Wx__PageSetupDialogData_GetEnablePrinter);
        newXS_deffile("Wx::PageSetupDialogData::GetEnableHelp", XS_Wx__PageSetupDialogData_GetEnableHelp);
        newXS_deffile("Wx::PageSetupDialogData::GetDefaultInfo", XS_Wx__PageSetupDialogData_GetDefaultInfo);
        newXS_deffile("Wx::PageSetupDialogData::GetMarginTopLeft", XS_Wx__PageSetupDialogData_GetMarginTopLeft);
        newXS_deffile("Wx::PageSetupDialogData::GetMarginBottomRight", XS_Wx__PageSetupDialogData_GetMarginBottomRight);
        newXS_deffile("Wx::PageSetupDialogData::GetMinMarginTopLeft", XS_Wx__PageSetupDialogData_GetMinMarginTopLeft);
        newXS_deffile("Wx::PageSetupDialogData::GetMinMarginBottomRight", XS_Wx__PageSetupDialogData_GetMinMarginBottomRight);
        newXS_deffile("Wx::PageSetupDialogData::GetPaperId", XS_Wx__PageSetupDialogData_GetPaperId);
        newXS_deffile("Wx::PageSetupDialogData::GetPaperSize", XS_Wx__PageSetupDialogData_GetPaperSize);
        newXS_deffile("Wx::PageSetupDialogData::GetPrintData", XS_Wx__PageSetupDialogData_GetPrintData);
        newXS_deffile("Wx::PageSetupDialogData::SetDefaultInfo", XS_Wx__PageSetupDialogData_SetDefaultInfo);
        newXS_deffile("Wx::PageSetupDialogData::SetDefaultMinMargins", XS_Wx__PageSetupDialogData_SetDefaultMinMargins);
        newXS_deffile("Wx::PageSetupDialogData::SetMarginTopLeft", XS_Wx__PageSetupDialogData_SetMarginTopLeft);
        newXS_deffile("Wx::PageSetupDialogData::SetMarginBottomRight", XS_Wx__PageSetupDialogData_SetMarginBottomRight);
        newXS_deffile("Wx::PageSetupDialogData::SetMinMarginTopLeft", XS_Wx__PageSetupDialogData_SetMinMarginTopLeft);
        newXS_deffile("Wx::PageSetupDialogData::SetMinMarginBottomRight", XS_Wx__PageSetupDialogData_SetMinMarginBottomRight);
        newXS_deffile("Wx::PageSetupDialogData::SetPaperId", XS_Wx__PageSetupDialogData_SetPaperId);
        newXS_deffile("Wx::PageSetupDialogData::SetPaperSize", XS_Wx__PageSetupDialogData_SetPaperSize);
        newXS_deffile("Wx::PageSetupDialogData::SetPrintData", XS_Wx__PageSetupDialogData_SetPrintData);
        newXS_deffile("Wx::PageSetupDialog::new", XS_Wx__PageSetupDialog_new);
        newXS_deffile("Wx::PageSetupDialog::Destroy", XS_Wx__PageSetupDialog_Destroy);
        newXS_deffile("Wx::PageSetupDialog::GetPageSetupData", XS_Wx__PageSetupDialog_GetPageSetupData);
        newXS_deffile("Wx::PageSetupDialog::ShowModal", XS_Wx__PageSetupDialog_ShowModal);
        newXS_deffile("Wx::PrintData::new", XS_Wx__PrintData_new);
        newXS_deffile("Wx::PrintData::Destroy", XS_Wx__PrintData_Destroy);
#if XSubPPtmpAAAN
        newXS_deffile("Wx::PrintData::GetBin", XS_Wx__PrintData_GetBin);
#endif
#if XSubPPtmpAAAO
        newXS_deffile("Wx::PrintData::IsOk", XS_Wx__PrintData_IsOk);
#endif
        newXS_deffile("Wx::PrintData::GetCollate", XS_Wx__PrintData_GetCollate);
        newXS_deffile("Wx::PrintData::GetColour", XS_Wx__PrintData_GetColour);
        newXS_deffile("Wx::PrintData::GetDuplex", XS_Wx__PrintData_GetDuplex);
        newXS_deffile("Wx::PrintData::GetNoCopies", XS_Wx__PrintData_GetNoCopies);
        newXS_deffile("Wx::PrintData::GetOrientation", XS_Wx__PrintData_GetOrientation);
        newXS_deffile("Wx::PrintData::GetPaperId", XS_Wx__PrintData_GetPaperId);
        newXS_deffile("Wx::PrintData::GetPrinterName", XS_Wx__PrintData_GetPrinterName);
        newXS_deffile("Wx::PrintData::GetQuality", XS_Wx__PrintData_GetQuality);
#if XSubPPtmpAAAP
        newXS_deffile("Wx::PrintData::SetBin", XS_Wx__PrintData_SetBin);
#endif
        newXS_deffile("Wx::PrintData::SetCollate", XS_Wx__PrintData_SetCollate);
        newXS_deffile("Wx::PrintData::SetColour", XS_Wx__PrintData_SetColour);
        newXS_deffile("Wx::PrintData::SetDuplex", XS_Wx__PrintData_SetDuplex);
        newXS_deffile("Wx::PrintData::SetNoCopies", XS_Wx__PrintData_SetNoCopies);
        newXS_deffile("Wx::PrintData::SetOrientation", XS_Wx__PrintData_SetOrientation);
        newXS_deffile("Wx::PrintData::SetPaperId", XS_Wx__PrintData_SetPaperId);
        newXS_deffile("Wx::PrintData::SetPrinterName", XS_Wx__PrintData_SetPrinterName);
        newXS_deffile("Wx::PrintData::SetQuality", XS_Wx__PrintData_SetQuality);
#if XSubPPtmpAAAQ
        newXS_deffile("Wx::PrintData::IsOrientationReversed", XS_Wx__PrintData_IsOrientationReversed);
        newXS_deffile("Wx::PrintData::GetPrintMode", XS_Wx__PrintData_GetPrintMode);
        newXS_deffile("Wx::PrintData::GetMedia", XS_Wx__PrintData_GetMedia);
        newXS_deffile("Wx::PrintData::SetOrientationReversed", XS_Wx__PrintData_SetOrientationReversed);
        newXS_deffile("Wx::PrintData::SetMedia", XS_Wx__PrintData_SetMedia);
        newXS_deffile("Wx::PrintData::SetPrintMode", XS_Wx__PrintData_SetPrintMode);
        newXS_deffile("Wx::PrintData::GetFilename", XS_Wx__PrintData_GetFilename);
        newXS_deffile("Wx::PrintData::SetFilename", XS_Wx__PrintData_SetFilename);
        newXS_deffile("Wx::PrintData::GetPrivData", XS_Wx__PrintData_GetPrivData);
        newXS_deffile("Wx::PrintData::GetPrivDataLen", XS_Wx__PrintData_GetPrivDataLen);
        newXS_deffile("Wx::PrintData::SetPrivData", XS_Wx__PrintData_SetPrivData);
        newXS_deffile("Wx::PrintData::ConvertToNative", XS_Wx__PrintData_ConvertToNative);
        newXS_deffile("Wx::PrintData::ConvertFromNative", XS_Wx__PrintData_ConvertFromNative);
#endif
        newXS_deffile("Wx::PreviewControlBar::new", XS_Wx__PreviewControlBar_new);
        newXS_deffile("Wx::PreviewControlBar::CreateButtons", XS_Wx__PreviewControlBar_CreateButtons);
        newXS_deffile("Wx::PreviewControlBar::GetPrintPreview", XS_Wx__PreviewControlBar_GetPrintPreview);
        newXS_deffile("Wx::PreviewControlBar::GetZoomControl", XS_Wx__PreviewControlBar_GetZoomControl);
        newXS_deffile("Wx::PreviewControlBar::SetZoomControl", XS_Wx__PreviewControlBar_SetZoomControl);
        newXS_deffile("Wx::PreviewControlBar::OnNext", XS_Wx__PreviewControlBar_OnNext);
        newXS_deffile("Wx::PreviewControlBar::OnPrevious", XS_Wx__PreviewControlBar_OnPrevious);
        newXS_deffile("Wx::PreviewControlBar::OnFirst", XS_Wx__PreviewControlBar_OnFirst);
        newXS_deffile("Wx::PreviewControlBar::OnLast", XS_Wx__PreviewControlBar_OnLast);
#if XSubPPtmpAAAR
        newXS_deffile("Wx::PreviewControlBar::OnGoto", XS_Wx__PreviewControlBar_OnGoto);
#endif
#if XSubPPtmpAAAS
        newXS_deffile("Wx::PreviewControlBar::OnGotoPage", XS_Wx__PreviewControlBar_OnGotoPage);
#endif
#if XSubPPtmpAAAT
        newXS_deffile("Wx::PreviewControlBar::OnPrint", XS_Wx__PreviewControlBar_OnPrint);
#endif
        newXS_deffile("Wx::PlPreviewControlBar::new", XS_Wx__PlPreviewControlBar_new);
        newXS_deffile("Wx::PlPreviewControlBar::CreateButtons", XS_Wx__PlPreviewControlBar_CreateButtons);
#if XSubPPtmpAAAU
        newXS_deffile("Wx::PreviewFrame::new", XS_Wx__PreviewFrame_new);
#endif
#if XSubPPtmpAAAV
        newXS_deffile("Wx::PreviewFrame::new", XS_Wx__PreviewFrame_new);
#endif
        newXS_deffile("Wx::PreviewFrame::Initialize", XS_Wx__PreviewFrame_Initialize);
        newXS_deffile("Wx::PreviewFrame::CreateCanvas", XS_Wx__PreviewFrame_CreateCanvas);
        newXS_deffile("Wx::PreviewFrame::CreateControlBar", XS_Wx__PreviewFrame_CreateControlBar);
#if XSubPPtmpAAAW
        newXS_deffile("Wx::PreviewFrame::GetControlBar", XS_Wx__PreviewFrame_GetControlBar);
#endif
#if XSubPPtmpAAAX
        newXS_deffile("Wx::PlPreviewFrame::new", XS_Wx__PlPreviewFrame_new);
#endif
#if XSubPPtmpAAAY
        newXS_deffile("Wx::PlPreviewFrame::new", XS_Wx__PlPreviewFrame_new);
#endif
#if XSubPPtmpAAAZ
        newXS_deffile("Wx::PlPreviewFrame::GetPreviewCanvas", XS_Wx__PlPreviewFrame_GetPreviewCanvas);
#endif
#if XSubPPtmpAABA
        newXS_deffile("Wx::PlPreviewFrame::GetPreviewCanvas", XS_Wx__PlPreviewFrame_GetPreviewCanvas);
#endif
        newXS_deffile("Wx::PlPreviewFrame::GetPreviewControlBar", XS_Wx__PlPreviewFrame_GetPreviewControlBar);
        newXS_deffile("Wx::PlPreviewFrame::GetPrintPreview", XS_Wx__PlPreviewFrame_GetPrintPreview);
#if XSubPPtmpAABB
        newXS_deffile("Wx::PlPreviewFrame::SetPreviewCanvas", XS_Wx__PlPreviewFrame_SetPreviewCanvas);
#endif
#if XSubPPtmpAABC
        newXS_deffile("Wx::PlPreviewFrame::SetPreviewCanvas", XS_Wx__PlPreviewFrame_SetPreviewCanvas);
#endif
        newXS_deffile("Wx::PlPreviewFrame::SetPreviewControlBar", XS_Wx__PlPreviewFrame_SetPreviewControlBar);
        newXS_deffile("Wx::PlPreviewFrame::SetPrintPreview", XS_Wx__PlPreviewFrame_SetPrintPreview);
        newXS_deffile("Wx::PlPreviewFrame::Initialize", XS_Wx__PlPreviewFrame_Initialize);
        newXS_deffile("Wx::PlPreviewFrame::CreateCanvas", XS_Wx__PlPreviewFrame_CreateCanvas);
        newXS_deffile("Wx::PlPreviewFrame::CreateControlBar", XS_Wx__PlPreviewFrame_CreateControlBar);
        newXS_deffile("Wx::PreviewCanvas::new", XS_Wx__PreviewCanvas_new);
#if XSubPPtmpAABD
        newXS_deffile("Wx::PrintFactory::CreatePrinter", XS_Wx__PrintFactory_CreatePrinter);
        newXS_deffile("Wx::PrintFactory::CreatePrintPreviewDD", XS_Wx__PrintFactory_CreatePrintPreviewDD);
        newXS_deffile("Wx::PrintFactory::CreatePrintPreviewD", XS_Wx__PrintFactory_CreatePrintPreviewD);
        newXS_deffile("Wx::PrintFactory::CreatePrintDialogDD", XS_Wx__PrintFactory_CreatePrintDialogDD);
        newXS_deffile("Wx::PrintFactory::CreatePrintDialogD", XS_Wx__PrintFactory_CreatePrintDialogD);
        newXS_deffile("Wx::PrintFactory::CreatePageSetupDialog", XS_Wx__PrintFactory_CreatePageSetupDialog);
        newXS_deffile("Wx::PrintFactory::HasPrintSetupDialog", XS_Wx__PrintFactory_HasPrintSetupDialog);
        newXS_deffile("Wx::PrintFactory::CreatePrintSetupDialog", XS_Wx__PrintFactory_CreatePrintSetupDialog);
        newXS_deffile("Wx::PrintFactory::HasOwnPrintToFile", XS_Wx__PrintFactory_HasOwnPrintToFile);
        newXS_deffile("Wx::PrintFactory::HasPrinterLine", XS_Wx__PrintFactory_HasPrinterLine);
        newXS_deffile("Wx::PrintFactory::CreatePrinterLine", XS_Wx__PrintFactory_CreatePrinterLine);
        newXS_deffile("Wx::PrintFactory::HasStatusLine", XS_Wx__PrintFactory_HasStatusLine);
        newXS_deffile("Wx::PrintFactory::CreateStatusLine", XS_Wx__PrintFactory_CreateStatusLine);
        newXS_deffile("Wx::PrintFactory::SetPrintFactory", XS_Wx__PrintFactory_SetPrintFactory);
        newXS_deffile("Wx::PrintFactory::GetFactory", XS_Wx__PrintFactory_GetFactory);
#endif
        newXS_deffile("Wx::PrintPaperType::GetName", XS_Wx__PrintPaperType_GetName);
        newXS_deffile("Wx::PrintPaperType::GetId", XS_Wx__PrintPaperType_GetId);
        newXS_deffile("Wx::PrintPaperType::GetPlatformId", XS_Wx__PrintPaperType_GetPlatformId);
        newXS_deffile("Wx::PrintPaperType::GetWidth", XS_Wx__PrintPaperType_GetWidth);
        newXS_deffile("Wx::PrintPaperType::GetHeight", XS_Wx__PrintPaperType_GetHeight);
        newXS_deffile("Wx::PrintPaperType::GetSize", XS_Wx__PrintPaperType_GetSize);
        newXS_deffile("Wx::PrintPaperType::GetSizeMM", XS_Wx__PrintPaperType_GetSizeMM);
        newXS_deffile("Wx::PrintPaperType::GetSizeDeviceUnits", XS_Wx__PrintPaperType_GetSizeDeviceUnits);
        newXS_deffile("Wx::PrintPaperDatabase::AddPaperType", XS_Wx__PrintPaperDatabase_AddPaperType);
        newXS_deffile("Wx::PrintPaperDatabase::FindPaperType", XS_Wx__PrintPaperDatabase_FindPaperType);
        newXS_deffile("Wx::PrintPaperDatabase::FindPaperTypeByName", XS_Wx__PrintPaperDatabase_FindPaperTypeByName);
        newXS_deffile("Wx::PrintPaperDatabase::FindPaperTypeById", XS_Wx__PrintPaperDatabase_FindPaperTypeById);
        newXS_deffile("Wx::PrintPaperDatabase::FindPaperTypeBySize", XS_Wx__PrintPaperDatabase_FindPaperTypeBySize);
        newXS_deffile("Wx::PrintPaperDatabase::FindPaperTypeByPlatformId", XS_Wx__PrintPaperDatabase_FindPaperTypeByPlatformId);
        newXS_deffile("Wx::PrintPaperDatabase::ConvertNameToId", XS_Wx__PrintPaperDatabase_ConvertNameToId);
        newXS_deffile("Wx::PrintPaperDatabase::ConvertIdToName", XS_Wx__PrintPaperDatabase_ConvertIdToName);
        newXS_deffile("Wx::PrintPaperDatabase::GetSize", XS_Wx__PrintPaperDatabase_GetSize);
        newXS_deffile("Wx::PrintPaperDatabase::GetSizeSize", XS_Wx__PrintPaperDatabase_GetSizeSize);
        newXS_deffile("Wx::PrintPaperDatabase::GetPaperSize", XS_Wx__PrintPaperDatabase_GetPaperSize);
        newXS_deffile("Wx::PrintPaperDatabase::Item", XS_Wx__PrintPaperDatabase_Item);
        newXS_deffile("Wx::PrintPaperDatabase::GetCount", XS_Wx__PrintPaperDatabase_GetCount);
#endif

    /* Initialisation Section */

  INIT_PLI_HELPERS( wx_pli_helpers );

#if XSubPPtmpAAAA
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#endif
#if XSubPPtmpAAAG
#endif
#if XSubPPtmpAAAH
#endif
#if XSubPPtmpAAAI
#endif
#if XSubPPtmpAAAJ
#endif
#if XSubPPtmpAAAK
#endif
#if XSubPPtmpAAAL
#endif
#if XSubPPtmpAAAM
#endif
#if XSubPPtmpAAAN
#endif
#if XSubPPtmpAAAO
#endif
#if XSubPPtmpAAAP
#endif
#if XSubPPtmpAAAQ
#endif
#if XSubPPtmpAAAR
#endif
#if XSubPPtmpAAAS
#endif
#if XSubPPtmpAAAT
#endif
#if XSubPPtmpAAAU
#endif
#if XSubPPtmpAAAV
#endif
#if XSubPPtmpAAAW
#endif
#if XSubPPtmpAAAX
#endif
#if XSubPPtmpAAAY
#endif
#if XSubPPtmpAAAZ
#endif
#if XSubPPtmpAABA
#endif
#if XSubPPtmpAABB
#endif
#if XSubPPtmpAABC
#endif
#if XSubPPtmpAABD
#endif
    {
        AV* isa = get_av( "Wx::PrintPaperType::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Object", 0 ) );
    } // blank line here is important

#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

